Get Prepped Model Info

get_prepped_models(run_info)

Arguments

run_info

run info using the set_run_info() function

Value

table with data related to model workflows, hyperparameters, and back testing

Examples

# \donttest{
data_tbl <- timetk::m4_monthly %>%
  dplyr::rename(Date = date) %>%
  dplyr::mutate(id = as.character(id)) %>%
  dplyr::filter(
    id == "M2",
    Date >= "2012-01-01",
    Date <= "2015-06-01"
  )

run_info <- set_run_info()
#> Finn Submission Info
#> • Project Name: finn_project
#> • Run Name: finn_fcst-20261008T175033Z
#> 

prep_data(run_info,
  input_data = data_tbl,
  combo_variables = c("id"),
  target_variable = "value",
  date_type = "month",
  forecast_horizon = 3,
  recipes_to_run = "R1"
)
#> ℹ Prepping Data
#> ✔ Prepping Data [371ms]
#> 

prep_models(run_info,
  models_to_run = c("arima", "ets"),
  num_hyperparameters = 1
)
#> ℹ Creating Model Workflows
#> ✔ Creating Model Workflows [74ms]
#> 
#> ℹ Creating Model Hyperparameters
#> ✔ Creating Model Hyperparameters [67ms]
#> 
#> ℹ Creating Train Test Splits
#> ℹ Turning ensemble models off since no multivariate models were chosen to run.
#> ℹ Creating Train Test Splits

#> ✔ Creating Train Test Splits [340ms]
#> 

prepped_models_tbl <- get_prepped_models(run_info = run_info)
# }