Name used to group similar runs under a
single experiment name.
run_name
Name to distinguish one run of Finn from another.
The current time in UTC is appended to the run name to ensure
a unique run name is created.
storage_object
Used to store outputs during a run to other
storage services in Azure. Could be a storage container object from
the 'AzureStor' package to connect to ADLS blob storage or a
OneDrive/SharePoint object from the 'Microsoft365R' package to connect
to a OneDrive folder or SharePoint site. Default of NULL will save outputs
to the local file system.
path
String showing what file path the outputs should be written to.
Default of NULL will write the outputs to a temporary directory within R,
which will delete itself after the R session closes.