MARS Multistep Horizon
mars_multistep(
mode = "regression",
num_terms = NULL,
prod_degree = NULL,
prune_method = NULL,
lag_periods = NULL,
external_regressors = NULL,
forecast_horizon = NULL,
selected_features = NULL
)A single character string for the type of model. The only possible value for this model is "regression".
The number of features that will be retained in the final model, including the intercept.
The highest possible interaction degree.
The pruning method.
lag periods
external regressors
forecast horizon
selected features
Get Multistep Horizon MARS model