SVM-RBF Multistep Horizon
svm_rbf_multistep(
mode = "regression",
cost = NULL,
rbf_sigma = NULL,
margin = NULL,
lag_periods = NULL,
external_regressors = NULL,
forecast_horizon = NULL,
selected_features = NULL
)A single character string for the type of model. The only possible value for this model is "regression".
A positive number for the cost of predicting a sample within or on the wrong side of the margin.
A positive number for radial basis function.
A positive number for the epsilon in the SVM insensitive loss function.
lag periods
external regressors
forecast horizon
selected features
Get Multistep Horizon SVM-RBF model