XGBOOST Multistep Horizon
xgboost_multistep(
mode = "regression",
mtry = NULL,
trees = NULL,
min_n = NULL,
tree_depth = NULL,
learn_rate = NULL,
loss_reduction = NULL,
sample_size = NULL,
stop_iter = NULL,
lag_periods = NULL,
external_regressors = NULL,
forecast_horizon = NULL,
selected_features = NULL
)A single character string for the type of model. The only possible value for this model is "regression".
mtry
trees
min_n
tree depth
learn rate
loss reduction
number for the number (or proportion) of data that is exposed to the fitting routine.
The number of iterations without improvement before stopping
lag periods
external regressors
forecast horizon
selected features
Get Multistep Horizon XGBoost model